Documentation
¶
Index ¶
- Constants
- type AnalyticsEventService
- func (vs *AnalyticsEventService) AddGeneralEvent(event XscAnalyticsGeneralEvent) (string, error)
- func (vs *AnalyticsEventService) GetGeneralEvent(msi string) (*XscAnalyticsGeneralEvent, error)
- func (vs *AnalyticsEventService) GetXscDetails() auth.ServiceDetails
- func (vs *AnalyticsEventService) UpdateGeneralEvent(event XscAnalyticsGeneralEventFinalize) error
- type EventStatus
- type EventType
- type ExternalErrorLog
- type LogErrorEventService
- type ProductName
- type VersionService
- type XscAnalyticsBasicGeneralEvent
- type XscAnalyticsGeneralEvent
- type XscAnalyticsGeneralEventFinalize
- type XscAnalyticsGeneralEventResponse
Constants ¶
const (
AnalyticsMetricsMinXscVersion = "1.7.1"
)
const (
LogErrorMinXscVersion = AnalyticsMetricsMinXscVersion
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnalyticsEventService ¶
type AnalyticsEventService struct {
XscDetails auth.ServiceDetails
// contains filtered or unexported fields
}
func NewAnalyticsEventService ¶
func NewAnalyticsEventService(client *jfroghttpclient.JfrogHttpClient) *AnalyticsEventService
func (*AnalyticsEventService) AddGeneralEvent ¶
func (vs *AnalyticsEventService) AddGeneralEvent(event XscAnalyticsGeneralEvent) (string, error)
AddGeneralEvent add general event in Xsc and returns msi generated by Xsc.
func (*AnalyticsEventService) GetGeneralEvent ¶
func (vs *AnalyticsEventService) GetGeneralEvent(msi string) (*XscAnalyticsGeneralEvent, error)
GetGeneralEvent returns event's data matching the provided multi scan id.
func (*AnalyticsEventService) GetXscDetails ¶
func (vs *AnalyticsEventService) GetXscDetails() auth.ServiceDetails
GetXscDetails returns the Xsc details
func (*AnalyticsEventService) UpdateGeneralEvent ¶
func (vs *AnalyticsEventService) UpdateGeneralEvent(event XscAnalyticsGeneralEventFinalize) error
UpdateGeneralEvent update finalized analytics metrics info of an existing event.
type EventStatus ¶
type EventStatus string
const ( Started EventStatus = "started" Completed EventStatus = "completed" Cancelled EventStatus = "cancelled" Failed EventStatus = "failed" )
type ExternalErrorLog ¶
type LogErrorEventService ¶
type LogErrorEventService struct {
XscDetails auth.ServiceDetails
// contains filtered or unexported fields
}
func NewLogErrorEventService ¶
func NewLogErrorEventService(client *jfroghttpclient.JfrogHttpClient) *LogErrorEventService
func (*LogErrorEventService) SendLogErrorEvent ¶
func (les *LogErrorEventService) SendLogErrorEvent(errorLog *ExternalErrorLog) error
type ProductName ¶
type ProductName string
const ( CliProduct ProductName = "cli" FrogbotProduct ProductName = "frogbot" )
type VersionService ¶
type VersionService struct {
XscDetails auth.ServiceDetails
// contains filtered or unexported fields
}
VersionService returns the https client and Xsc details
func NewVersionService ¶
func NewVersionService(client *jfroghttpclient.JfrogHttpClient) *VersionService
NewVersionService creates a new service to retrieve the version of Xsc
func (*VersionService) GetVersion ¶
func (vs *VersionService) GetVersion() (string, error)
GetVersion returns the version of Xsc
func (*VersionService) GetXscDetails ¶
func (vs *VersionService) GetXscDetails() auth.ServiceDetails
GetXscDetails returns the Xsc details
type XscAnalyticsBasicGeneralEvent ¶
type XscAnalyticsBasicGeneralEvent struct {
EventType EventType `json:"event_type,omitempty"`
EventStatus EventStatus `json:"event_status,omitempty"`
Product ProductName `json:"product,omitempty"`
ProductVersion string `json:"product_version,omitempty"`
TotalFindings int `json:"total_findings,omitempty"`
TotalIgnoredFindings int `json:"total_ignored_findings,omitempty"`
IsDefaultConfig bool `json:"is_default_config,omitempty"`
JfrogUser string `json:"jfrog_user,omitempty"`
OsPlatform string `json:"os_platform,omitempty"`
OsArchitecture string `json:"os_architecture,omitempty"`
MachineId string `json:"machine_id,omitempty"`
AnalyzerManagerVersion string `json:"analyzer_manager_version,omitempty"`
JpdVersion string `json:"jpd_version,omitempty"`
TotalScanDuration string `json:"total_scan_duration,omitempty"`
FrogbotScanType string `json:"frogbot_scan_type,omitempty"`
FrogbotCiProvider string `json:"frogbot_ci_provider,omitempty"`
}
type XscAnalyticsGeneralEvent ¶
type XscAnalyticsGeneralEvent struct {
XscAnalyticsBasicGeneralEvent
GitInfo *services.XscGitInfoContext `json:"gitinfo,omitempty"`
IsGitInfoFlow bool `json:"is_gitinfo_flow,omitempty"`
}
XscAnalyticsGeneralEvent extend the basic struct with Frogbot related info.
type XscAnalyticsGeneralEventFinalize ¶
type XscAnalyticsGeneralEventFinalize struct {
XscAnalyticsBasicGeneralEvent
MultiScanId string `json:"multi_scan_id,omitempty"`
}
type XscAnalyticsGeneralEventResponse ¶
type XscAnalyticsGeneralEventResponse struct {
MultiScanId string `json:"multi_scan_id,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.